@@ -24,6 +24,7 @@ Usage:
   opereto environment <environment-name>
   opereto globals list [<search_pattern>]
   opereto diagnostics <from_iso_date> <to_iso_date> [--file=OUTPUT_FILE]
+  opereto test [--testplan_pid=TESTPLAN_PID] [--verbose]
   opereto token
   opereto (-h | --help)
   opereto --version
@@ -67,6 +68,7 @@ Options:
 
     token                : Show the current token details
     diagnostics          : Generates a diagnostics file. Requires a few additional python packages
+    test                 : Run opereto benchmark test
 
     -h,--help            : Show this help message
     --version            : Show this tool version
@@ -87,6 +89,8 @@ import tempfile
 import subprocess
 import re
 import traceback
+import importlib
+from datetime import datetime, timedelta
 from docopt import docopt
 from distutils.version import LooseVersion
 from pyopereto.client import OperetoClient, OperetoClientError, process_running_statuses
@@ -95,7 +99,6 @@ from pyopereto.diagnostics import run_diagnostics
 logging.getLogger("matplotlib").propagate = False
 logging.getLogger('matplotlib').setLevel(logging.ERROR)
 
-
 try:
     VERSION = pkg_resources.get_distribution("pyopereto").version
 except:
@@ -165,6 +168,10 @@ def get_opereto_client():
     return client
 
 
+def create_dir_if_not_exist(folder):
+    if not os.path.exists(folder):
+        os.makedirs(folder)
+
 def print_token(params):
     client = get_opereto_client()
     print(client.get_current_username)
@@ -696,6 +703,41 @@ def _check_for_upgrade():
         logger.error('Failed to check for latest pyopereto version: {}'.format(str(e)))
 
 
+def opereto_test(arguments):
+
+    pytest_params = ['-v', '-s', '--show-capture=no', '--tb=no']
+    if arguments['--verbose']:
+        pytest_params = ['-v', '-s']
+
+    os.environ['OPERETO_TEST_BENCHMAR_TESTPLAN_PID'] = ''
+    tid = arguments['--testplan_pid']
+    if tid:
+        os.environ['OPERETO_TEST_BENCHMAR_TESTPLAN_PID']=tid
+
+    required_packages = ['pytest']
+    for package in required_packages:
+        if not importlib.util.find_spec(package):
+            raise Exception(
+                f'Opereto test command requires the following python packages {str(required_packages)}. Please install them and then re-run this command.')
+
+    import pytest
+
+    try:
+        print('Running Opereto benchmark test (may take a few minutes)...')
+        startdate = datetime.utcnow() - timedelta(hours=1)
+        pytest.main(pytest_params)
+
+        ## run diagnostics
+        enddate = datetime.utcnow()
+        test_results_file = os.path.join(TEMP_DIR, 'opereto_test_results.json')
+        with open(test_results_file, 'r') as result_file:
+            results = json.loads(result_file.read())
+            run_diagnostics(startdate.isoformat(), enddate.isoformat(), output_file=os.path.join(HOME_DIR,f'opereto-test-{enddate}.pdf'), test_results=results)
+    finally:
+        if os.path.exists(test_results_file):
+            os.remove(test_results_file)
+
+
 def diagnostics(arguments):
 
     startdate = arguments['<from_iso_date>']
@@ -759,6 +801,8 @@ def main():
             print_token(arguments)
         elif arguments['diagnostics']:
             diagnostics(arguments)
+        elif arguments['test']:
+            opereto_test(arguments)
 
     except Exception as e:
         logger.error(str(e))
